
# How to Install
```shell
pip install osintradar
```
# How to Use It
```python
from osintradar import osintradar
response = osintradar("test.com")
print(response)
```

### Allowed Asset Types
- Url
- Domain
- Ipv4
